/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

<Ejemplo Capitulo 5: Ejemplo utilizando wxChoice, wxComboBox, wxListBox, wxCheckBox y wxRadioBox.>
Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/


#ifndef _CHAPTER_05_H_
#define _CHAPTER_05_H_

#include <wx/wx.h>

/**
 * @brief Clase que modela la aplicacion. Esta compuesta por <i>Frames</i>.
 * @author David Casas Molina
 * @date 3 de enero de 2010
 ^ @note Parte del proyecto wxTutorial.
 */
class MyApp : public wxApp 
{
public:
   /**
    * Metodo virtual que arranca la aplicacion.
    * @return Booleano que indica si la aplicacion se ha ejecutado con exito o no.
    */
   virtual bool OnInit();
};


/**
 * @brief Clase que modela un <i>Frames</i>. En ella se definen todos los componentes queramos que contenga.
 * @author David Casas Molina
 * @date 3 de enero de 2010
 ^ @note Parte del proyecto wxTutorial.
 */
class MyFrame : public wxFrame
{
public:
   /**
    * Constructor de la clase MyFrame.
    * @param title Titulo del <i>Frames</i>.
    */
   MyFrame(const wxString& title);
   
   /**
    * Manejador del evento <code>OnChoice()</code>.
    * @param event Referencia al comando del evento <code>OnChoice()</code>.
    */
   void OnChoice(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnComboBox()</code>.
    * @param event Referencia al comando del evento <code>OnComboBox()</code>.
    */
   void OnComboBox(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnCheckBox()</code>.
    * @param event Referencia al comando del evento <code>OnCheckBox()</code>.
    */
   void OnCheckBoxBold(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnListBoxBold()</code>.
    * @param event Referencia al comando del evento <code>OnListBoxBold()</code>.
    */
   void OnCheckBoxItalic(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnListBoxItalic()</code>.
    * @param event Referencia al comando del evento <code>OnListBoxBoldItalic()</code>.
    */
   void OnCheckBoxUnderline(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnListBoxBoldUnderline()</code>.
    * @param event Referencia al comando del evento <code>OnListBoxBoldUnderline()</code>.
    */
   void OnListBox(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnRadioBox()</code>.
    * @param event Referencia al comando del evento <code>OnRadioBox()</code>.
    */
   void OnRadioBox(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnQuit()</code>.
    * @param event Referencia al comando del evento <code>OnQuit()</code>.
    */
   void OnExit(wxCommandEvent& event);
   
private:
   /**
    * Puntero a un StaticText, que utilizaremos para etiquetar las fuentes.
    */
   wxStaticText *lblFont;
   /**
    * Puntero a un StaticText, que utilizaremos para etiquetar los estilos predeterminados.
    */
   wxStaticText *lblchoice;
   /**
    * Puntero a un StaticText, que utilizaremos para etiquetar los estilos.
    */
   wxStaticText *lblStyle;
   /**
    * Puntero a un StaticText, que utilizaremos para etiquetar el tamao.
    */
   wxStaticText *lblSize;
   /**
    * Puntero a un StaticText, que utilizaremos para etiquetar el texto.
    */
   wxStaticText *lblText;
   /**
    * Puntero a un Choice, que utilizaremos para estilos predefinidos.
    */
   wxChoice *choice;
   /**
    * Puntero a un ComboBox, que utilizaremos para modificar la fuente.
    */
   wxComboBox *cbFont;
    /**
    * Puntero a un ListBox, que utilizaremos para modificar el tamao.
    */
   wxListBox *lbSize;
   /**
    * Puntero a CheckBox, que utilizaremos para modificar el estilo (negrita).
    */
   wxCheckBox *ckStyleBl;
   /**
    * Puntero a CheckBox, que utilizaremos para modificar el estilo (cursiva).
    */
   wxCheckBox *ckStyleIt;
   /**
    * Puntero a CheckBox, que utilizaremos para modificar el estilo (subrayado).
    */
   wxCheckBox *ckStyleUn;
   /**
    * Puntero a RadioBox, que utilizaremos para modificar el color.
    */
   wxRadioBox *rbColor;
   /**
    * Puntero a un cuadro de texto, que utilizaremos para introducir el texto.
    */
   wxTextCtrl *tcText;
   /*
    * Puntero a un boton, que utilizaremos para salir del programa.
    */
   wxButton *btnExit;
   
   /**
    * Declaracion de la tabla de eventos del <i>Frame</i>.
    */
   DECLARE_EVENT_TABLE()
};

DECLARE_APP(MyApp)

#endif
