
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

< wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/

#include "path.h"
#include "form.h"

enum idMain {
  ID_SearchPage = 0,
  ID_SearchExample,
  ID_DownloadCode,
  ID_DownloadExecutable,
};

BEGIN_EVENT_TABLE(Form, wxFrame)

EVT_MENU(wxID_DEFAULT, Form::OnRestore)
EVT_MENU(wxID_PREFERENCES, Form::OnExport)
//EVT_MENU(wxID_PRINT, Form::OnPrint)
EVT_MENU(wxID_EXIT, Form::OnExit)

EVT_MENU(ID_SearchPage, Form::OnContents)
EVT_MENU(ID_SearchExample, Form::OnExample)

EVT_MENU(ID_DownloadCode, Form::OnSourceCode)
EVT_MENU(ID_DownloadExecutable, Form::OnExecutable)

EVT_MENU(wxID_HELP, Form::OnManual)
EVT_MENU(wxID_ABOUT, Form::OnAbout)

EVT_BUTTON(wxID_EXIT, Form::OnExit)
EVT_BUTTON(wxID_HELP, Form::OnManual)

END_EVENT_TABLE()


Form::Form(const wxString& title, const wxPoint& pos, const wxSize& size):
wxFrame((wxFrame*)NULL, -1, title, pos, size,
	wxSYSTEM_MENU | wxCLOSE_BOX | wxMINIMIZE_BOX | wxCAPTION | wxICONIZE)
{

  menufile = new wxMenu();
  menufile->Append(wxID_DEFAULT, wxString::FromUTF8("&Restaurar"));
  menufile->Append(wxID_PREFERENCES, wxString::FromUTF8("E&xportar"));
  menufile->AppendSeparator();
  //menufile->Append(wxID_PRINT, wxString::FromUTF8("&Imprimir"));
  //menufile->AppendSeparator();
  menufile->Append(wxID_EXIT, wxString::FromUTF8("Salir"));

  menushow = new wxMenu();
  menushow->Append(ID_SearchPage, wxString::FromUTF8("Co&ntenido"));
  menushow->Append(ID_SearchExample, wxString::FromUTF8("E&jemplo"));

  menudownload = new wxMenu();
  menudownload->Append(ID_DownloadCode, wxString::FromUTF8("Códig&o Fuente"));
  menudownload->Append(ID_DownloadExecutable, wxString::FromUTF8("Ejec&utable"));

  menuhelp = new wxMenu();
  menuhelp->Append(wxID_HELP, wxString::FromUTF8("Manual"));
  menuhelp->AppendSeparator();
  menuhelp->Append(wxID_ABOUT, wxString::FromUTF8("A&cerca de.."));

  menubar = new wxMenuBar();
  menubar->Append(menufile, wxString::FromUTF8("&Archivo"));
  menubar->Append(menushow, wxString::FromUTF8("&Ver"));
  menubar->Append(menudownload, wxString::FromUTF8("&Descargar"));
  menubar->Append(menuhelp, wxString::FromUTF8("A&yuda"));

  SetMenuBar(menubar);
  
  /* Iniciamos los manejadores de imágenes al principo
     para poder incluir imágenes en los archivos html. */

  wxInitAllImageHandlers();
  
  // Para cuando tengamos una imagen del icono.ico...
  wxImage image = wxImage(120,120);

#ifdef __WXGTK__
  image.LoadFile(wxString::FromUTF8("./iconos/wxfavicon_grande.png"), wxBITMAP_TYPE_PNG);
#endif
#ifdef __WXMSW__
  image.LoadFile(wxString::FromUTF8("./iconos/wxfavicon_16.ico"), wxBITMAP_TYPE_ICO);
#endif
  wxIcon icon = wxIcon();
  icon.CopyFromBitmap(wxBitmap(image));
  SetIcon(icon);

  // Contenedor donde se crearán las tres partes de la aplicación:
  // . Visor de HTML, 
  // . Navegación por todas las funcionalidades.
  // . Los botones de ayuda y salir.
  panel = new wxPanel(this, wxID_ANY, wxPoint(0,0), wxDefaultSize);

  // Inicialización de componentes visor y navegador.
  html = new Viewer(panel, wxID_ANY, wxPoint(10,10), wxSize(550,480));
  html->LoadPage(Path::GetPathHtml(0));
  nav = new Navigator(panel, wxPoint(600,35), wxSize(400,370));

  // Asociación entre ambos para poder visualizar los archivos seleccionados
  // en el navegador dentro del visor.
  html->Nav(nav);
  nav->ViewerHtml(html);

  // Inicialización de los botones con imágenes.
  wxImage imagebutton = wxImage(48,48);
 
  imagebutton.LoadFile(Path::GetPathPicture(4), wxBITMAP_TYPE_PNG);
  buttonhelp = new wxBitmapButton(panel, wxID_HELP, wxBitmap(imagebutton), wxPoint(800,430));

  imagebutton.LoadFile(Path::GetPathPicture(5), wxBITMAP_TYPE_PNG);
  buttonexit = new wxBitmapButton(panel, wxID_EXIT, wxBitmap(imagebutton), wxPoint(900,430));

}

/* --------------- eventos ----------------------- */
/* ---------- Menu Principal (Archivo) ----------- */
void Form::OnRestore(wxCommandEvent& event)
{
  html->LoadPage(Path::GetPathHtml(0));
  nav->Restore();
}

void Form::OnExport(wxCommandEvent& event)
{
  menuexport = new DialogExport(this, wxID_ANY, 
				wxString::FromUTF8("Exportar artículo: "));
  menuexport->ShowModal();

  if(menuexport->GetReturnCode() == wxID_OK){
    menuexport->Process();
  }
    
  /* wxMessageBox(wxString::Format(_T("%d"), menuExp->GetReturnCode()));
  wxMessageBox(wxString::Format(_T("%d"), wxID_OK));
  wxMessageBox(wxString::Format(_T("%d"), wxID_CANCEL)); */
}

//void Form::OnPrint(wxCommandEvent& event)
//{
//}

void Form::OnExit(wxCommandEvent& event)
{
  Close();
}

/* ---------- Menu Principal (Ver) --------------- */
void Form::OnContents(wxCommandEvent& event)
{
  menuchapter = new DialogShowChapter(this, wxID_ANY, 
				      wxString::FromUTF8("Visualizar un artículo: ")); 
  menuchapter->ShowModal();

  if(menuchapter->GetReturnCode() == wxID_OK){
    html->LoadPage(Path::GetPathHtml(menuchapter->Process()));
  }
}

void Form::OnExample(wxCommandEvent& event)
{
  menuexample = new DialogShowExample(this, wxID_ANY, 
			      wxString::FromUTF8("Visualizar un ejemplo: "));
  menuexample->ShowModal();

  if(menuexample->GetReturnCode() == wxID_OK){
    if(menuexample->Process() != -1)
      html->LoadPage(Path::GetPathCode(menuexample->Process()));
    if(menuexample->Example() != -1){
      menushowimage = new DialogImage(this, wxID_ANY, wxString::FromUTF8("Imágenes"),
				      menuexample->Example());
      menushowimage->ShowModal();
    }
  }
}


/* ---------- Menu Principal (Descargar) --------- */
void Form::OnSourceCode(wxCommandEvent& event)
{
  menucode = new DialogDownloadCode(this, wxID_ANY, wxString::FromUTF8("Descargar código: "));
  menucode->ShowModal();

  if(menucode->GetReturnCode() == wxID_OK){
    menucode->Process();
  }
}

void Form::OnExecutable(wxCommandEvent& event)
{
  menuexe = new DialogDownloadExe(this, wxID_ANY, wxString::FromUTF8("Descargar ejecutable: "));
  menuexe->ShowModal();
  
  if(menuexe->GetReturnCode() == wxID_OK){
    menuexe->Process();
  }
}

/* ---------- Menu Principal (Ayuda) ------------- */
void Form::OnManual(wxCommandEvent& event)
{
  #ifdef __WXMSW__
  system("start ./contenido/manual_wxtutorial.pdf");
  #endif

  #ifdef __WXGTK__
  system("evince ./contenido/manual_wxtutorial.pdf");
  #endif
  // Abrir el manual en pdf (no hay un diálogo específico para los manuales).
}

void Form::OnAbout(wxCommandEvent& event)
{
  aboutas =  wxAboutDialogInfo();
  aboutas.AddDeveloper(wxString::FromUTF8("David Casas Molina"));
  aboutas.AddDeveloper(wxString::FromUTF8("Jose Galván Montesinos"));
  aboutas.AddDeveloper(wxString::FromUTF8("Rosa María Durante Lerate"));

  aboutas.AddDocWriter(wxString::FromUTF8("Rosa María Durante Lerate"));
  aboutas.SetDescription(wxString::FromUTF8("wxTutorial! es una forma fácil, entretenida y eficaz de aprender a manejar los aspectos más básicos de la biblioteca wxWidgets"));
  
  wxImage image = wxImage(120,120);
  image.LoadFile(wxString::FromUTF8("./iconos/wxfavicon_grande.png"), wxBITMAP_TYPE_PNG);
  wxIcon icon = wxIcon();
  icon.CopyFromBitmap(wxBitmap(image));
  aboutas.SetIcon(icon);
 
  aboutas.SetName(wxString::FromUTF8("wxTutorial!"));
  aboutas.SetCopyright(wxString::FromUTF8("(C) 2010 R.Durante D.Casas J.Galván\n <rosa.durantelerate@alum.uca.es>"));
  aboutas.SetVersion(wxString::FromUTF8("version 0.7 (alpha)"));
  aboutas.SetWebSite(wxString::FromUTF8("https://forja.rediris.es/projects/wxtutorial/"), wxString::FromUTF8("Enlace al repositorio SVN del proyecto alojado en RedIris"));

  aboutas.SetLicense(Path::GetLicense());

  wxAboutBox(aboutas);
  
}
