
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */
 
#ifndef _FORM_
#define _FORM_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/aboutdlg.h>

#include "nav.h"
#include "viewer.h"

#include "dexp.h"
#include "dimag.h"
#include "dshow.h"
#include "ddl.h"

/**
 * @brief Definición del formulario de la aplicación.
 * 
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class Form : public wxFrame {
 public:
  /**
   * @brief Constructor de la clase.
   * @param title Título de la ventana.
   * @param pos Posición de la ventana en la pantalla.
   * @param size Tamaño de la ventana, es decir,
   * de la aplicación.
   */
  Form(const wxString& title, const wxPoint& pos, const wxSize& size);
 
  /**
   * @brief Función que define el comportamiento
   * para el evento de restaurar la aplicación.
   * @param event Evento producido en la aplicación.
   */
  void OnRestore(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento
   * para el evento de exportar contenido a PDF.
   * @param event Evento producido en la aplicación.
   */
  void OnExport(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento
   * para el evento de salir de la aplicación.
   * @param event Evento producido en la aplicación.
   */
  void OnExit(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento
   * para el evento de visualización del contenido.
   * @param event Evento producido en la aplicación.
   */
  void OnContents(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento
   * para el evento de visualización de ejemplos.
   * @param event Evento producido en la aplicación.
   */
  void OnExample(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento
   * para el evento de descarga de código de los
   * ejemplos.
   * @param event Evento producido en la aplicación.
   */
  void OnSourceCode(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento
   * para el evento de descarga del ejecutable
   * de los ejercicios.
   * @param event Evento producido en la aplicación.
   */
  void OnExecutable(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento
   * para el evento de la visualización del manual
   * de usuario.
   * @param event Evento producido en la aplicación.
   */
  void OnManual(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento
   * para el evento de mostrar la información del
   * la aplicación.
   * @param event Evento producido en la aplicación.
   */
  void OnAbout(wxCommandEvent& event);
 
 private:
  wxMenu *menufile, *menushow, *menudownload, *menuhelp;
  wxMenuBar *menubar;

  wxPanel *panel;
  Viewer *html;
  Navigator *nav;

  wxBitmapButton *buttonhelp;
  wxBitmapButton *buttonexit;
  
  DialogExport *menuexport;
  DialogShowChapter *menuchapter;
  DialogShowExample *menuexample;
  DialogDownloadCode *menucode;
  DialogDownloadExe *menuexe;
  DialogImage *menushowimage;
  wxAboutDialogInfo aboutas;

  DECLARE_EVENT_TABLE()
 };

#endif
